@@ -22,23 +22,21 @@
 
 #include "previewplugin.h"
 
-#include <QTextDocument>
 #include <QTextCursor>
 
 using namespace Milou;
 
-PreviewPlugin::PreviewPlugin(QObject* parent)
+PreviewPlugin::PreviewPlugin(QObject *parent)
     : QObject(parent)
     , m_context(nullptr)
 {
-
 }
 
 PreviewPlugin::~PreviewPlugin()
 {
 }
 
-void PreviewPlugin::setUrl(const QUrl& url)
+void PreviewPlugin::setUrl(const QUrl &url)
 {
     m_url = url;
 }
@@ -48,7 +46,7 @@ QUrl PreviewPlugin::url() const
     return m_url;
 }
 
-void PreviewPlugin::setMimetype(const QString& mimetype)
+void PreviewPlugin::setMimetype(const QString &mimetype)
 {
     m_mimetype = mimetype;
 }
@@ -58,7 +56,7 @@ QString PreviewPlugin::mimetype() const
     return m_mimetype;
 }
 
-void PreviewPlugin::setHighlight(const QString& term)
+void PreviewPlugin::setHighlight(const QString &term)
 {
     m_highlight = term;
 }
@@ -68,29 +66,27 @@ QString PreviewPlugin::highlight() const
     return m_highlight;
 }
 
-void PreviewPlugin::setContext(QQmlContext* context)
+void PreviewPlugin::setContext(QQmlContext *context)
 {
     m_context = context;
 }
 
-QQmlContext* PreviewPlugin::context()
+QQmlContext *PreviewPlugin::context()
 {
     Q_ASSERT(m_context);
     return m_context;
 }
 
-void PreviewPlugin::highlight(const QTextDocument* doc) const
+void PreviewPlugin::highlight(const QTextDocument *doc) const
 {
     QTextCursor cursor;
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    Q_FOREACH (const QString& text, highlight().split(QLatin1Char(' '), QString::SkipEmptyParts)) {
-#else
-    Q_FOREACH (const QString& text, highlight().split(QLatin1Char(' '), Qt::SkipEmptyParts)) {
-#endif
+    const QStringList highlights = highlight().split(QLatin1Char(' '), Qt::SkipEmptyParts);
+    for (const QString &text : highlights) {
         while (1) {
             cursor = doc->find(text, cursor);
-            if (cursor.isNull())
+            if (cursor.isNull()) {
                 break;
+            }
 
             QString selection = cursor.selectedText();
 
